@@ -4,7 +4,7 @@ from django.utils import timezone
 from caluma.caluma_core.events import send_event
 
 from ..caluma_form.models import Document
-from . import events, models, utils, validators
+from . import api, events, models, utils, validators
 
 
 class StartCaseLogic:
@@ -113,7 +113,7 @@ class CompleteWorkItemLogic:
         )
 
     @staticmethod
-    def pre_complete(validated_data, user):
+    def pre_complete(work_item, validated_data, user, context=None):
         validated_data["status"] = models.WorkItem.STATUS_COMPLETED
         validated_data["closed_at"] = timezone.now()
         validated_data["closed_by_user"] = user.username
@@ -196,15 +196,26 @@ class CompleteWorkItemLogic:
 class SkipWorkItemLogic:
     @staticmethod
     def validate_for_skip(work_item):
+        if work_item.case.status != models.Case.STATUS_RUNNING:
+            raise ValidationError("Only work items of running cases can be skipped.")
+
         if work_item.status != models.WorkItem.STATUS_READY:
-            raise ValidationError("Only READY work items can be skipped")
+            raise ValidationError("Only ready work items can be skipped.")
 
     @staticmethod
-    def pre_skip(validated_data, user):
-        validated_data = CompleteWorkItemLogic.pre_complete(validated_data, user)
+    def pre_skip(work_item, validated_data, user, context=None):
+        validated_data = CompleteWorkItemLogic.pre_complete(
+            work_item, validated_data, user, context
+        )
 
         validated_data["status"] = models.WorkItem.STATUS_SKIPPED
 
+        if (
+            work_item.child_case
+            and work_item.child_case.status == models.Case.STATUS_RUNNING
+        ):
+            api.cancel_case(work_item.child_case, user, context)
+
         return validated_data
 
     @staticmethod
@@ -224,10 +235,10 @@ class SkipWorkItemLogic:
 
 class CancelCaseLogic:
     """
-    Shared domain logic for cancelling cases.
+    Shared domain logic for canceling cases.
 
     Used in the `cancelCase` mutation and in the `cancel_case` API. The logic
-    for case cancellation is split in three parts (`validate_for_cancel`,
+    for case cancelation is split in three parts (`validate_for_cancel`,
     `pre_cancel` and `post_cancel`) so that in between the appropriate update
     method can be called (`super().update(...)` for the serializer and
     `Case.objects.update(...) for the python API`).
@@ -235,44 +246,30 @@ class CancelCaseLogic:
 
     @staticmethod
     def validate_for_cancel(case):
-        if case.status != models.Case.STATUS_RUNNING:
-            raise ValidationError("Only running cases can be canceled.")
+        if case.status not in [
+            models.Case.STATUS_RUNNING,
+            models.Case.STATUS_SUSPENDED,
+        ]:
+            raise ValidationError("Only running or suspended cases can be canceled.")
 
     @staticmethod
-    def pre_cancel(validated_data, user):
+    def pre_cancel(case, validated_data, user, context=None):
         validated_data["status"] = models.Case.STATUS_CANCELED
         validated_data["closed_at"] = timezone.now()
         validated_data["closed_by_user"] = user.username
         validated_data["closed_by_group"] = user.group
 
+        for work_item in case.work_items.filter(
+            status__in=[models.WorkItem.STATUS_READY, models.WorkItem.STATUS_SUSPENDED]
+        ):
+            api.cancel_work_item(work_item, user, context)
+
         return validated_data
 
     @staticmethod
     def post_cancel(case, user, context=None):
-        work_items = case.work_items.exclude(
-            status__in=[
-                models.WorkItem.STATUS_COMPLETED,
-                models.WorkItem.STATUS_CANCELED,
-            ]
-        )
-
-        for work_item in work_items:
-            work_item.status = models.WorkItem.STATUS_CANCELED
-            work_item.closed_at = timezone.now()
-            work_item.closed_by_user = user.username
-            work_item.closed_by_group = user.group
-            work_item.save()
-
-        # send events in separate loop in order to be sure all operations are finished
-        for work_item in work_items:
-            send_event(
-                events.cancelled_work_item,
-                sender="post_cancel_case",
-                work_item=work_item,
-                user=user,
-                context=context,
-            )
-
+        # TODO: remove in the next major release since `events.cancelled_case`
+        # is deprecated in favor of `events.canceled_case`
         send_event(
             events.cancelled_case,
             sender="post_cancel_case",
@@ -281,26 +278,124 @@ class CancelCaseLogic:
             context=context,
         )
 
+        send_event(
+            events.canceled_case,
+            sender="post_cancel_case",
+            case=case,
+            user=user,
+            context=context,
+        )
+
+        return case
+
+
+class SuspendCaseLogic:
+    """
+    Shared domain logic for suspending cases.
+
+    Used in the `suspendCase` mutation and in the `suspend_case` API. The logic
+    for case suspension is split in three parts (`validate_for_suspend`,
+    `pre_suspend` and `post_suspend`) so that in between the appropriate update
+    method can be called (`super().update(...)` for the serializer and
+    `Case.objects.update(...) for the python API`).
+    """
+
+    @staticmethod
+    def validate_for_suspend(case):
+        if case.status != models.Case.STATUS_RUNNING:
+            raise ValidationError("Only running cases can be suspended.")
+
+    @staticmethod
+    def pre_suspend(case, validated_data, user, context=None):
+        validated_data["status"] = models.Case.STATUS_SUSPENDED
+
+        for work_item in case.work_items.filter(status=models.WorkItem.STATUS_READY):
+            api.suspend_work_item(work_item, user, context)
+
+        return validated_data
+
+    @staticmethod
+    def post_suspend(case, user, context=None):
+        send_event(
+            events.suspended_case,
+            sender="post_suspend_case",
+            case=case,
+            user=user,
+            context=context,
+        )
+
+        return case
+
+
+class ResumeCaseLogic:
+    """
+    Shared domain logic for resuming cases.
+
+    Used in the `resumeCase` mutation and in the `resume_case` API. The logic
+    for resuming a case is split in three parts (`validate_for_resume`,
+    `pre_resume` and `post_resume`) so that in between the appropriate update
+    method can be called (`super().update(...)` for the serializer and
+    `Case.objects.update(...) for the python API`).
+    """
+
+    @staticmethod
+    def validate_for_resume(case):
+        if case.status != models.Case.STATUS_SUSPENDED:
+            raise ValidationError("Only suspended cases can be resumed.")
+
+    @staticmethod
+    def pre_resume(case, validated_data, user, context=None):
+        validated_data["status"] = models.Case.STATUS_RUNNING
+
+        for work_item in case.work_items.filter(
+            status=models.WorkItem.STATUS_SUSPENDED
+        ):
+            api.resume_work_item(work_item, user, context)
+
+        return validated_data
+
+    @staticmethod
+    def post_resume(case, user, context=None):
+        send_event(
+            events.resumed_case,
+            sender="post_resume_case",
+            case=case,
+            user=user,
+            context=context,
+        )
+
         return case
 
 
 class CancelWorkItemLogic:
     @staticmethod
     def validate_for_cancel(work_item):
-        if work_item.status != models.WorkItem.STATUS_READY:
-            raise ValidationError("Only READY work items can be cancelled")
+        if work_item.status not in [
+            models.WorkItem.STATUS_READY,
+            models.WorkItem.STATUS_SUSPENDED,
+        ]:
+            raise ValidationError("Only ready or suspended work items can be canceled.")
 
     @staticmethod
-    def pre_cancel(validated_data, user):
+    def pre_cancel(work_item, validated_data, user, context=None):
         validated_data["status"] = models.WorkItem.STATUS_CANCELED
         validated_data["closed_at"] = timezone.now()
         validated_data["closed_by_user"] = user.username
         validated_data["closed_by_group"] = user.group
 
+        if work_item.child_case and work_item.child_case.status in [
+            models.Case.STATUS_RUNNING,
+            models.Case.STATUS_SUSPENDED,
+        ]:
+            api.cancel_case(work_item.child_case, user, context)
+
         return validated_data
 
     @staticmethod
     def post_cancel(work_item, user, context=None):
+        # TODO: remove in the next major release since
+        # `events.cancelled_work_item` is deprecated in favor of
+        # `events.canceled_work_item`
         send_event(
             events.cancelled_work_item,
             sender="post_cancel_work_item",
@@ -309,4 +404,74 @@ class CancelWorkItemLogic:
             context=context,
         )
 
+        send_event(
+            events.canceled_work_item,
+            sender="post_cancel_work_item",
+            work_item=work_item,
+            user=user,
+            context=context,
+        )
+
+        return work_item
+
+
+class SuspendWorkItemLogic:
+    @staticmethod
+    def validate_for_suspend(work_item):
+        if work_item.status != models.WorkItem.STATUS_READY:
+            raise ValidationError("Only ready work items can be suspended.")
+
+    @staticmethod
+    def pre_suspend(work_item, validated_data, user, context=None):
+        validated_data["status"] = models.WorkItem.STATUS_SUSPENDED
+
+        if (
+            work_item.child_case
+            and work_item.child_case.status == models.Case.STATUS_RUNNING
+        ):
+            api.suspend_case(work_item.child_case, user, context)
+
+        return validated_data
+
+    @staticmethod
+    def post_suspend(work_item, user, context=None):
+        send_event(
+            events.suspended_work_item,
+            sender="post_suspend_work_item",
+            work_item=work_item,
+            user=user,
+            context=context,
+        )
+
+        return work_item
+
+
+class ResumeWorkItemLogic:
+    @staticmethod
+    def validate_for_resume(work_item):
+        if work_item.status != models.WorkItem.STATUS_SUSPENDED:
+            raise ValidationError("Only suspended work items can be resumed.")
+
+    @staticmethod
+    def pre_resume(work_item, validated_data, user, context=None):
+        validated_data["status"] = models.WorkItem.STATUS_READY
+
+        if (
+            work_item.child_case
+            and work_item.child_case.status == models.Case.STATUS_SUSPENDED
+        ):
+            api.resume_case(work_item.child_case, user, context)
+
+        return validated_data
+
+    @staticmethod
+    def post_resume(work_item, user, context=None):
+        send_event(
+            events.resumed_work_item,
+            sender="post_resume_work_item",
+            work_item=work_item,
+            user=user,
+            context=context,
+        )
+
         return work_item
