@@ -33,7 +33,7 @@ def case_status_filter(*args, **kwargs):
 
     enum = graphene.Enum(
         "CaseStatusArgument",
-        [(i.upper(), i) for i in models.Case.STATUS_CHOICES],
+        [(key.upper(), key) for (key, desc) in models.Case.STATUS_CHOICE_TUPLE],
         type=EnumWithDescriptionsType,
     )
     return generate_list_filter_class(enum)(*args, **kwargs)
@@ -200,6 +200,7 @@ class WorkItemFilterSet(MetaFilterSet):
     document_has_answer = HasAnswerFilter(document_id="document__pk")
     case_document_has_answer = HasAnswerFilter(document_id="case__document__pk")
     case_meta_value = JSONValueFilter(field_name="case__meta")
+    root_case_meta_value = JSONValueFilter(field_name="case__family__meta")
 
     tasks = SlugMultipleChoiceFilter(field_name="task_id")
 
