@@ -202,11 +202,13 @@ class CaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
 
 
 class SaveCaseSerializer(CaseSerializer):
+    @transaction.atomic
     def create(self, validated_data):
         instance = super().create(validated_data)
         self.send_event(events.created_case)
         return instance
 
+    @transaction.atomic
     def update(self, instance, validated_data):
         instance = super().update(instance, validated_data)
         self.send_event(events.created_case, case=instance)
@@ -232,16 +234,81 @@ class CancelCaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
         return super().validate(data)
 
     @transaction.atomic
-    def update(self, instance, validated_data):
+    def update(self, case, validated_data):
         user = self.context["request"].user
 
         super().update(
-            instance, domain_logic.CancelCaseLogic.pre_cancel(validated_data, user)
+            case,
+            domain_logic.CancelCaseLogic.pre_cancel(
+                case, validated_data, user, self.context_data
+            ),
         )
 
-        domain_logic.CancelCaseLogic.post_cancel(instance, user, self.context_data)
+        domain_logic.CancelCaseLogic.post_cancel(case, user, self.context_data)
 
-        return instance
+        return case
+
+
+class SuspendCaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
+    id = serializers.GlobalIDField()
+
+    class Meta:
+        model = models.Case
+        fields = ("id", "context")
+
+    def validate(self, data):
+        try:
+            domain_logic.SuspendCaseLogic.validate_for_suspend(self.instance)
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
+
+        return super().validate(data)
+
+    @transaction.atomic
+    def update(self, case, validated_data):
+        user = self.context["request"].user
+
+        super().update(
+            case,
+            domain_logic.SuspendCaseLogic.pre_suspend(
+                case, validated_data, user, self.context_data
+            ),
+        )
+
+        domain_logic.SuspendCaseLogic.post_suspend(case, user, self.context_data)
+
+        return case
+
+
+class ResumeCaseSerializer(SendEventSerializerMixin, ContextModelSerializer):
+    id = serializers.GlobalIDField()
+
+    class Meta:
+        model = models.Case
+        fields = ("id", "context")
+
+    def validate(self, data):
+        try:
+            domain_logic.ResumeCaseLogic.validate_for_resume(self.instance)
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
+
+        return super().validate(data)
+
+    @transaction.atomic
+    def update(self, case, validated_data):
+        user = self.context["request"].user
+
+        super().update(
+            case,
+            domain_logic.ResumeCaseLogic.pre_resume(
+                case, validated_data, user, self.context_data
+            ),
+        )
+
+        domain_logic.ResumeCaseLogic.post_resume(case, user, self.context_data)
+
+        return case
 
 
 class CompleteWorkItemSerializer(ContextModelSerializer):
@@ -262,7 +329,7 @@ class CompleteWorkItemSerializer(ContextModelSerializer):
         user = self.context["request"].user
 
         validated_data = domain_logic.CompleteWorkItemLogic.pre_complete(
-            validated_data, user
+            work_item, validated_data, user, self.context_data
         )
 
         work_item = super().update(work_item, validated_data)
@@ -288,10 +355,13 @@ class SkipWorkItemSerializer(ContextModelSerializer):
 
         return super().validate(data)
 
+    @transaction.atomic
     def update(self, work_item, validated_data):
         user = self.context["request"].user
 
-        validated_data = domain_logic.SkipWorkItemLogic.pre_skip(validated_data, user)
+        validated_data = domain_logic.SkipWorkItemLogic.pre_skip(
+            work_item, validated_data, user, self.context_data
+        )
 
         work_item = super().update(work_item, validated_data)
         work_item = domain_logic.SkipWorkItemLogic.post_skip(
@@ -316,11 +386,12 @@ class CancelWorkItemSerializer(ContextModelSerializer):
 
         return super().validate(data)
 
+    @transaction.atomic
     def update(self, work_item, validated_data):
         user = self.context["request"].user
 
         validated_data = domain_logic.CancelWorkItemLogic.pre_cancel(
-            validated_data, user
+            work_item, validated_data, user, self.context_data
         )
 
         work_item = super().update(work_item, validated_data)
@@ -350,6 +421,7 @@ class SaveWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer):
         help_text=models.WorkItem._meta.get_field("description").help_text,
     )
 
+    @transaction.atomic
     def update(self, instance, validated_data):
         instance = super().update(instance, validated_data)
         self.send_event(events.created_work_item, work_item=instance)
@@ -424,6 +496,7 @@ class CreateWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer)
 
         return super().validate(data)
 
+    @transaction.atomic
     def create(self, validated_data):
         instance = super().create(validated_data)
         self.send_event(events.created_work_item, work_item=instance)
@@ -443,3 +516,65 @@ class CreateWorkItemSerializer(SendEventSerializerMixin, ContextModelSerializer)
             "meta",
             "context",
         )
+
+
+class SuspendWorkItemSerializer(ContextModelSerializer):
+    id = serializers.GlobalIDField()
+
+    def validate(self, data):
+        try:
+            domain_logic.SuspendWorkItemLogic.validate_for_suspend(self.instance)
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
+
+        return super().validate(data)
+
+    @transaction.atomic
+    def update(self, work_item, validated_data):
+        user = self.context["request"].user
+
+        validated_data = domain_logic.SuspendWorkItemLogic.pre_suspend(
+            work_item, validated_data, user, self.context_data
+        )
+
+        work_item = super().update(work_item, validated_data)
+        work_item = domain_logic.SuspendWorkItemLogic.post_suspend(
+            work_item, user, self.context_data
+        )
+
+        return work_item
+
+    class Meta:
+        model = models.WorkItem
+        fields = ("id", "context")
+
+
+class ResumeWorkItemSerializer(ContextModelSerializer):
+    id = serializers.GlobalIDField()
+
+    def validate(self, data):
+        try:
+            domain_logic.ResumeWorkItemLogic.validate_for_resume(self.instance)
+        except ValidationError as e:
+            raise exceptions.ValidationError(str(e))
+
+        return super().validate(data)
+
+    @transaction.atomic
+    def update(self, work_item, validated_data):
+        user = self.context["request"].user
+
+        validated_data = domain_logic.ResumeWorkItemLogic.pre_resume(
+            work_item, validated_data, user, self.context_data
+        )
+
+        work_item = super().update(work_item, validated_data)
+        work_item = domain_logic.ResumeWorkItemLogic.post_resume(
+            work_item, user, self.context_data
+        )
+
+        return work_item
+
+    class Meta:
+        model = models.WorkItem
+        fields = ("id", "context")
